package de.bsvrz.sys.usv.gui.swing;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Font;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.GridLayout;
import java.awt.Insets;
import java.awt.Toolkit;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.util.ArrayList;

import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.border.TitledBorder;

import de.bsvrz.sys.usv.enums.BatterieZustand;
import de.bsvrz.sys.usv.enums.EingangsfrequenzZustand;
import de.bsvrz.sys.usv.enums.KommunikationsZustand;
import de.bsvrz.sys.usv.enums.USVZustand;
import de.bsvrz.sys.usv.enums.WechselSpannung;
import de.bsvrz.sys.usv.enums.ZustandNotstrom;
import de.bsvrz.sys.usv.enums.ZustandPhase;
import de.bsvrz.sys.usv.wrapper.USVAllgemein;
import de.bsvrz.sys.usv.wrapper.USVWrapper;
import de.bsvrz.sys.usv.wrapper.UsvKonstanten;

/**
 * Grafische Testumgebung für SWE 10.3 USV-Wrapper. Man kann hiermit nur die
 * Schnittstelle testen, die konkreten Implementierungen der Schnittstelle für
 * die einzelnen USVs wird nicht mit abgedeckt.
 *
 *
 * @author BitCtrl Systems GmbH, Christian Hösel
 */
public class SimuGUIJFrame extends JFrame implements USVAllgemein {

	private static final long serialVersionUID = 1L;
	private JPanel jContentPane = null;

	private USVZustand m_UsvZustand = USVZustand.na;
	private int m_BatterieZustand = BatterieZustand.na.getValue();
	private KommunikationsZustand m_KommunikationsZustand = KommunikationsZustand.na;
	private EingangsfrequenzZustand m_EingangsFrequenzZustand = EingangsfrequenzZustand.na;
	private WechselSpannung m_WechselSpannung = WechselSpannung.na;
	private ZustandPhase m_ZustandPhase1 = ZustandPhase.na;
	private ZustandPhase m_ZustandPhase2 = ZustandPhase.na;
	private ZustandPhase m_ZustandPhase3 = ZustandPhase.na;
	private ZustandNotstrom m_ZustandNotstrom = ZustandNotstrom.na;
	private int batterieSpannung = -1;
	private int batterieRestlaufzeit = -1;
	private int batterieTemperatur = -1;
	private int batterieBetriebsdauer = -1;

	private USVWrapper m_instance;

	private JPanel jPanelOben = null;
	private JPanel jPanelUnten = null;
	private JButton jButtonUebernehmen = null;
	private JButton jButtonSchliessen = null;
	private JComboBox jComboBoxUsvZustand = null;
	private JPanel jPanelAusgabe = null;
	private JLabel jLabelBefehlNotstrom = null;
	private JLabel jLabelBefehlUsvBetrieb = null;
	private JTextField jTextFieldBefehlNotstrom = null;
	private JTextField jTextFieldBefehlUsvBetrieb = null;
	private JComboBox jComboBoxBatterieZustand = null;
	private JComboBox jComboBoxKommunikationsZustand = null;
	private JComboBox jComboBoxEingangsFrequenzZustand = null;
	private JComboBox jComboBoxWechselspannung = null;
	private JComboBox jComboBoxZustandPhase1 = null;
	private JComboBox jComboBoxZustandPhase2 = null;
	private JComboBox jComboBoxZustandPhase3 = null;
	private JComboBox jComboBoxZustandNotstrom = null;
	private JComboBox jComboBoxBatterieSpannung = null;
	private JComboBox jComboBoxBatterieTemperatur = null;
	private JComboBox jComboBoxBatterieRestlaufzeit = null;
	private JComboBox jComboBoxBatterieBetriebsdauer = null;

	/**
	 * Konstruktor
	 *
	 */
	public SimuGUIJFrame() {
		super();

		initialize();
		setVisible(true);
	}

	/**
	 * This method initializes this
	 *
	 */
	private void initialize() {
		this.setSize(400, 411);
		setContentPane(getJContentPane());
		setTitle("USV-Simulation (SWING)");

		/*
		 * Zentrieren des JFrames
		 */
		final Dimension bildschirmGroesse = Toolkit.getDefaultToolkit().getScreenSize();
		final int y = (bildschirmGroesse.height - this.getSize().height) / 2;
		final int x = (bildschirmGroesse.width - this.getSize().width) / 2;
		this.setLocation(x, y);

		addWindowListener(new WindowAdapter() {

			@Override
			public void windowClosing(final WindowEvent e) {
				System.out.println("Closing");
				aktionSchliessen();
			}
		});
	}

	/**
	 * This method initializes jContentPane
	 *
	 * @return javax.swing.JPanel
	 */
	private JPanel getJContentPane() {
		if (jContentPane == null) {
			final GridBagConstraints gridBagConstraints11 = new GridBagConstraints();
			gridBagConstraints11.gridx = 0;
			gridBagConstraints11.weightx = 1.0;
			gridBagConstraints11.fill = GridBagConstraints.HORIZONTAL;
			gridBagConstraints11.gridy = 1;
			final GridBagConstraints gridBagConstraints1 = new GridBagConstraints();
			gridBagConstraints1.gridx = 0;
			gridBagConstraints1.ipadx = 0;
			gridBagConstraints1.weightx = 1.0;
			gridBagConstraints1.fill = GridBagConstraints.HORIZONTAL;
			gridBagConstraints1.gridy = 2;
			final GridBagConstraints gridBagConstraints = new GridBagConstraints();
			gridBagConstraints.gridx = 0;
			gridBagConstraints.fill = GridBagConstraints.BOTH;
			gridBagConstraints.weightx = 1.0;
			gridBagConstraints.weighty = 1.0;
			gridBagConstraints.gridy = 0;
			jContentPane = new JPanel();
			jContentPane.setLayout(new GridBagLayout());
			jContentPane.add(getJPanelOben(), gridBagConstraints);
			jContentPane.add(getJPanelUnten(), gridBagConstraints1);
			jContentPane.add(getJPanelAusgabe(), gridBagConstraints11);
		}
		return jContentPane;
	}

	/**
	 * This method initializes jPanelOben
	 *
	 * @return javax.swing.JPanel
	 */
	private JPanel getJPanelOben() {
		if (jPanelOben == null) {
			jPanelOben = new JPanel();
			jPanelOben.setLayout(new GridLayout(0, 2));
			jPanelOben.setBorder(
					BorderFactory.createTitledBorder(null, "Einstellungen", TitledBorder.DEFAULT_JUSTIFICATION,
							TitledBorder.DEFAULT_POSITION, new Font("Dialog", Font.BOLD, 12), new Color(51, 51, 51)));

			jPanelOben.add(new JLabel("Zustand Phase3:"));
			jPanelOben.add(getJComboBoxZustandPhase3());

			jPanelOben.add(new JLabel("Zustand Phase2:"));
			jPanelOben.add(getJComboBoxZustandPhase2());

			jPanelOben.add(new JLabel("Zustand Phase1:"));
			jPanelOben.add(getJComboBoxZustandPhase1());

			jPanelOben.add(new JLabel("Wechsel Spannung:"));
			jPanelOben.add(getJComboBoxWechselspannung());

			jPanelOben.add(new JLabel("Eingangs Frequenz Zustand:"));
			jPanelOben.add(getJComboBoxEingangsFrequenzZustand());

			jPanelOben.add(new JLabel("Kommunikations Zustand:"));
			jPanelOben.add(getJComboBoxKommunikationsZustand());

			jPanelOben.add(new JLabel("Batterie Zustand:"));
			jPanelOben.add(getJComboBoxBatterieZustand());

			jPanelOben.add(new JLabel("Usv Zustand:"));
			jPanelOben.add(getJComboBoxUsvZustand());

			jPanelOben.add(new JLabel("Zustand Notstrom:"));
			jPanelOben.add(getJComboBoxZustandNotstrom());

			jPanelOben.add(new JLabel("Batteriebetriebsdauer:"));
			jPanelOben.add(getJComboBoxBatterieBetriebsdauer());

			jPanelOben.add(new JLabel("Batteriespannung:"));
			jPanelOben.add(getJComboBoxBatterieSpannung());

			jPanelOben.add(new JLabel("Batterietemperatur:"));
			jPanelOben.add(getJComboBoxBatterieTemperatur());

			jPanelOben.add(new JLabel("Batterierestlaufzeit:"));
			jPanelOben.add(getJComboboxBatterieRestlaufzeit());
		}
		return jPanelOben;
	}

	/**
	 * This method initializes jPanelUnten
	 *
	 * @return javax.swing.JPanel
	 */
	private JPanel getJPanelUnten() {
		if (jPanelUnten == null) {
			jPanelUnten = new JPanel();
			jPanelUnten.setLayout(new FlowLayout());
			jPanelUnten.setBorder(BorderFactory.createLineBorder(Color.gray, 1));
			jPanelUnten.add(getJButtonUebernehmen(), null);
			jPanelUnten.add(getJButtonSchliessen(), null);
		}
		return jPanelUnten;
	}

	/**
	 * Übernimmt die getroffenen Einstellungen
	 */
	private void aktionUebernehmen() {
		int s;

		m_UsvZustand = (USVZustand) jComboBoxUsvZustand.getSelectedItem();
		if ((s = jComboBoxBatterieZustand.getSelectedIndex()) != -1) {
			m_BatterieZustand = s - 1;
		}

		m_KommunikationsZustand = (KommunikationsZustand) jComboBoxKommunikationsZustand.getSelectedItem();

		m_EingangsFrequenzZustand = (EingangsfrequenzZustand) jComboBoxEingangsFrequenzZustand.getSelectedItem();

		m_WechselSpannung = (WechselSpannung) jComboBoxWechselspannung.getSelectedItem();

		m_ZustandPhase1 = (ZustandPhase) jComboBoxZustandPhase1.getSelectedItem();

		m_ZustandPhase2 = (ZustandPhase) jComboBoxZustandPhase2.getSelectedItem();

		m_ZustandPhase3 = (ZustandPhase) jComboBoxZustandPhase3.getSelectedItem();

		m_ZustandNotstrom = (ZustandNotstrom) jComboBoxZustandNotstrom.getSelectedItem();

		if ((s = jComboBoxBatterieBetriebsdauer.getSelectedIndex()) != -1) {
			batterieBetriebsdauer = s - 1;
		}

		if ((s = jComboBoxBatterieRestlaufzeit.getSelectedIndex()) != -1) {
			batterieRestlaufzeit = s - 1;
		}

		if ((s = jComboBoxBatterieSpannung.getSelectedIndex()) != -1) {
			batterieSpannung = s - 1;
		}

		if ((s = jComboBoxBatterieTemperatur.getSelectedIndex()) != -1) {
			batterieTemperatur = s - 1;
		}

		m_instance.setTrigger();
	}

	/**
	 * This method initializes jButtonUebernehmen
	 *
	 * @return javax.swing.JButton
	 */
	private JButton getJButtonUebernehmen() {
		if (jButtonUebernehmen == null) {
			jButtonUebernehmen = new JButton();
			jButtonUebernehmen.setText("Übernehmen");
			jButtonUebernehmen.addMouseListener(new java.awt.event.MouseAdapter() {
				@Override
				public void mouseClicked(final java.awt.event.MouseEvent e) {
					aktionUebernehmen();
				}
			});
		}
		return jButtonUebernehmen;
	}

	private void aktionSchliessen() {
		setVisible(false);
		dispose();
		System.exit(0); // Knallhart!
	}

	/**
	 * This method initializes jButtonSchliessen
	 *
	 * @return javax.swing.JButton
	 */
	private JButton getJButtonSchliessen() {
		if (jButtonSchliessen == null) {
			jButtonSchliessen = new JButton();
			jButtonSchliessen.setText("Schließen");
			jButtonSchliessen.addMouseListener(new java.awt.event.MouseAdapter() {
				@Override
				public void mouseClicked(final java.awt.event.MouseEvent e) {
					aktionSchliessen();
				}
			});
		}
		return jButtonSchliessen;
	}

	/**
	 * This method initializes jComboBoxUsvZustand
	 *
	 * @return javax.swing.JComboBox
	 */
	private JComboBox getJComboBoxUsvZustand() {

		if (jComboBoxUsvZustand == null) {
			jComboBoxUsvZustand = new JComboBox(USVZustand.values());
			jComboBoxUsvZustand.setSelectedIndex(0);
		}
		return jComboBoxUsvZustand;
	}

	/**
	 * This method initializes jPanelAusgabe
	 *
	 * @return javax.swing.JPanel
	 */
	private JPanel getJPanelAusgabe() {
		if (jPanelAusgabe == null) {
			final GridBagConstraints gridBagConstraints7 = new GridBagConstraints();
			gridBagConstraints7.fill = GridBagConstraints.BOTH;
			gridBagConstraints7.gridy = 1;
			gridBagConstraints7.weightx = 1.0;
			gridBagConstraints7.insets = new Insets(2, 2, 2, 2);
			gridBagConstraints7.gridx = 1;
			final GridBagConstraints gridBagConstraints6 = new GridBagConstraints();
			gridBagConstraints6.fill = GridBagConstraints.BOTH;
			gridBagConstraints6.gridy = 0;
			gridBagConstraints6.weightx = 1.0;
			gridBagConstraints6.insets = new Insets(2, 2, 2, 2);
			gridBagConstraints6.gridx = 1;
			final GridBagConstraints gridBagConstraints5 = new GridBagConstraints();
			gridBagConstraints5.anchor = GridBagConstraints.NORTHWEST;
			final GridBagConstraints gridBagConstraints4 = new GridBagConstraints();
			gridBagConstraints4.gridx = 0;
			gridBagConstraints4.anchor = GridBagConstraints.NORTHWEST;
			gridBagConstraints4.gridy = 1;
			jLabelBefehlUsvBetrieb = new JLabel();
			jLabelBefehlUsvBetrieb.setText("Befehl UsvBetrieb:");
			jLabelBefehlNotstrom = new JLabel();
			jLabelBefehlNotstrom.setText("Befehl Notstrom:");
			jPanelAusgabe = new JPanel();
			jPanelAusgabe.setLayout(new GridBagLayout());
			jPanelAusgabe
					.setBorder(BorderFactory.createTitledBorder(null, "Ausgabe", TitledBorder.DEFAULT_JUSTIFICATION,
							TitledBorder.DEFAULT_POSITION, new Font("Dialog", Font.BOLD, 12), new Color(51, 51, 51)));
			jPanelAusgabe.add(jLabelBefehlNotstrom, gridBagConstraints5);
			jPanelAusgabe.add(jLabelBefehlUsvBetrieb, gridBagConstraints4);
			jPanelAusgabe.add(getJTextFieldBefehlNotstrom(), gridBagConstraints6);
			jPanelAusgabe.add(getJTextFieldBefehlUsvBetrieb(), gridBagConstraints7);
		}
		return jPanelAusgabe;
	}

	/**
	 * This method initializes jTextFieldBefehlNotstrom
	 *
	 * @return javax.swing.JTextField
	 */
	private JTextField getJTextFieldBefehlNotstrom() {
		if (jTextFieldBefehlNotstrom == null) {
			jTextFieldBefehlNotstrom = new JTextField();
			jTextFieldBefehlNotstrom.setEditable(false);
			jTextFieldBefehlNotstrom.setText("-");
		}
		return jTextFieldBefehlNotstrom;
	}

	/**
	 * This method initializes jTextFieldBefehlUsvBetrieb
	 *
	 * @return javax.swing.JTextField
	 */
	private JTextField getJTextFieldBefehlUsvBetrieb() {
		if (jTextFieldBefehlUsvBetrieb == null) {
			jTextFieldBefehlUsvBetrieb = new JTextField();
			jTextFieldBefehlUsvBetrieb.setEditable(false);
			jTextFieldBefehlUsvBetrieb.setText("-");
		}
		return jTextFieldBefehlUsvBetrieb;
	}

	/**
	 * This method initializes jComboBoxBatterieZustand
	 *
	 * @return javax.swing.JComboBox
	 */
	private JComboBox getJComboBoxBatterieZustand() {
		if (jComboBoxBatterieZustand == null) {
			final ArrayList<String> al = new ArrayList<String>();
			al.add(BatterieZustand.na.getText());
			for (int i = 0; i <= 100; i++) {
				al.add(i + " %");
			}

			String[] vals = new String[al.size()];
			vals = al.toArray(vals);

			jComboBoxBatterieZustand = new JComboBox(vals);
			jComboBoxBatterieZustand.setSelectedIndex(0);

		}
		return jComboBoxBatterieZustand;
	}

	private JComboBox getJComboBoxBatterieSpannung() {
		if (jComboBoxBatterieSpannung == null) {
			final ArrayList<String> al = new ArrayList<String>();
			al.add(UsvKonstanten.nicht_ermittelbar);
			for (int i = 0; i <= 10000; i++) {
				al.add(i + " V");
			}

			String[] vals = new String[al.size()];
			vals = al.toArray(vals);

			jComboBoxBatterieSpannung = new JComboBox(vals);
			jComboBoxBatterieSpannung.setSelectedIndex(0);

		}
		return jComboBoxBatterieSpannung;
	}

	private JComboBox getJComboBoxBatterieBetriebsdauer() {
		if (jComboBoxBatterieBetriebsdauer == null) {
			final ArrayList<String> al = new ArrayList<String>();
			al.add(UsvKonstanten.nicht_ermittelbar);
			for (int i = 0; i <= 10000; i++) {
				al.add(i + " s");
			}

			String[] vals = new String[al.size()];
			vals = al.toArray(vals);

			jComboBoxBatterieBetriebsdauer = new JComboBox(vals);
			jComboBoxBatterieBetriebsdauer.setSelectedIndex(0);

		}
		return jComboBoxBatterieBetriebsdauer;
	}

	private JComboBox getJComboboxBatterieRestlaufzeit() {
		if (jComboBoxBatterieRestlaufzeit == null) {
			final ArrayList<String> al = new ArrayList<String>();
			al.add(UsvKonstanten.nicht_ermittelbar);
			for (int i = 0; i <= 1000; i++) {
				al.add(i + " m");
			}

			String[] vals = new String[al.size()];
			vals = al.toArray(vals);

			jComboBoxBatterieRestlaufzeit = new JComboBox(vals);
			jComboBoxBatterieRestlaufzeit.setSelectedIndex(0);

		}
		return jComboBoxBatterieRestlaufzeit;
	}

	private JComboBox getJComboBoxBatterieTemperatur() {
		if (jComboBoxBatterieTemperatur == null) {
			final ArrayList<String> al = new ArrayList<String>();
			al.add(UsvKonstanten.nicht_ermittelbar);
			for (int i = 0; i <= 100; i++) {
				al.add(i + " °C");
			}

			String[] vals = new String[al.size()];
			vals = al.toArray(vals);

			jComboBoxBatterieTemperatur = new JComboBox(vals);
			jComboBoxBatterieTemperatur.setSelectedIndex(0);

		}
		return jComboBoxBatterieTemperatur;
	}

	/**
	 * This method initializes jComboBoxKommunikationsZustand
	 *
	 * @return javax.swing.JComboBox
	 */
	private JComboBox getJComboBoxKommunikationsZustand() {
		if (jComboBoxKommunikationsZustand == null) {
			jComboBoxKommunikationsZustand = new JComboBox(KommunikationsZustand.values());
			jComboBoxKommunikationsZustand.setSelectedIndex(0);
		}
		return jComboBoxKommunikationsZustand;
	}

	/**
	 * This method initializes jComboBoxEingangsFrequenzZustand
	 *
	 * @return javax.swing.JComboBox
	 */
	private JComboBox getJComboBoxEingangsFrequenzZustand() {
		if (jComboBoxEingangsFrequenzZustand == null) {
			jComboBoxEingangsFrequenzZustand = new JComboBox(EingangsfrequenzZustand.values());
			jComboBoxEingangsFrequenzZustand.setSelectedIndex(0);
		}
		return jComboBoxEingangsFrequenzZustand;
	}

	/**
	 * This method initializes jComboBoxWechselspannung
	 *
	 * @return javax.swing.JComboBox
	 */
	private JComboBox getJComboBoxWechselspannung() {
		if (jComboBoxWechselspannung == null) {
			jComboBoxWechselspannung = new JComboBox(WechselSpannung.values());
			jComboBoxWechselspannung.setSelectedIndex(0);
		}
		return jComboBoxWechselspannung;
	}

	/**
	 * This method initializes jComboBoxZustandPhase1
	 *
	 * @return javax.swing.JComboBox
	 */
	private JComboBox getJComboBoxZustandPhase1() {
		if (jComboBoxZustandPhase1 == null) {
			jComboBoxZustandPhase1 = new JComboBox(ZustandPhase.values());
			jComboBoxZustandPhase1.setSelectedIndex(0);
		}
		return jComboBoxZustandPhase1;
	}

	/**
	 * This method initializes jComboBoxZustandPhase2
	 *
	 * @return javax.swing.JComboBox
	 */
	private JComboBox getJComboBoxZustandPhase2() {
		if (jComboBoxZustandPhase2 == null) {
			jComboBoxZustandPhase2 = new JComboBox(ZustandPhase.values());
			jComboBoxZustandPhase2.setSelectedIndex(0);
		}
		return jComboBoxZustandPhase2;
	}

	/**
	 * This method initializes jComboBoxZustandPhase3
	 *
	 * @return javax.swing.JComboBox
	 */
	private JComboBox getJComboBoxZustandPhase3() {
		if (jComboBoxZustandPhase3 == null) {
			jComboBoxZustandPhase3 = new JComboBox(ZustandPhase.values());
			jComboBoxZustandPhase3.setSelectedIndex(0);
		}
		return jComboBoxZustandPhase3;
	}

	/**
	 * This method initializes jComboBoxZustandNotstrom
	 *
	 * @return javax.swing.JComboBox
	 */
	private JComboBox getJComboBoxZustandNotstrom() {
		if (jComboBoxZustandNotstrom == null) {
			jComboBoxZustandNotstrom = new JComboBox(ZustandNotstrom.values());
			jComboBoxZustandNotstrom.setSelectedIndex(0);
		}
		return jComboBoxZustandNotstrom;
	}

	/**
	 * Methode zum Aulesen der Membervariablen
	 *
	 * @return m_UsvZustand
	 */
	@Override
	public USVZustand getUsvZustand() {
		return m_UsvZustand;
	}

	/**
	 * Methode zum Aulesen der Membervariablen
	 *
	 * @return m_BatterieZustand
	 */
	@Override
	public int getBatterieZustand() {
		return m_BatterieZustand;
	}

	/**
	 * Methode zum Aulesen der Membervariablen
	 *
	 * @return m_KommunikationsZustand
	 */
	@Override
	public KommunikationsZustand getKommunikationsZustand() {
		return m_KommunikationsZustand;
	}

	/**
	 * Methode zum Aulesen der Membervariablen
	 *
	 * @return m_EingangsFrequenzZustand
	 */
	@Override
	public EingangsfrequenzZustand getEingangsFrequenzZustand() {
		return m_EingangsFrequenzZustand;
	}

	/**
	 * Methode zum Aulesen der Membervariablen
	 *
	 * @return m_WechselSpannung
	 */
	@Override
	public WechselSpannung getWechselSpannung() {
		return m_WechselSpannung;
	}

	/**
	 * Methode zum Aulesen der Membervariablen
	 *
	 * @return m_ZustandPhase1
	 */
	@Override
	public ZustandPhase getZustandPhase1() {
		return m_ZustandPhase1;
	}

	/**
	 * Methode zum Aulesen der Membervariablen
	 *
	 * @return m_ZustandPhase2
	 */
	@Override
	public ZustandPhase getZustandPhase2() {
		return m_ZustandPhase2;
	}

	/**
	 * Methode zum Aulesen der Membervariablen
	 *
	 * @return m_ZustandPhase2
	 */
	@Override
	public ZustandPhase getZustandPhase3() {
		return m_ZustandPhase3;
	}

	/**
	 * Methode zum Aulesen der Membervariablen
	 *
	 * @return m_ZustandPhase3
	 */
	@Override
	public ZustandNotstrom getZustandNotstrom() {
		return m_ZustandNotstrom;
	}

	/**
	 * Methode zum Setzen der Membervariablen m_BefehlNotstrom
	 *
	 * @return 0  Funktion erfolgreich durchgeführt 1  Funktion nicht
	 *         erfolgreich durchgeführt -1  Funktionalität nicht implementiert.
	 */
	@Override
	public int setNotstrom(final boolean befehl) {
		if (befehl) {
			jTextFieldBefehlNotstrom.setText("aktiv");
		} else {
			jTextFieldBefehlNotstrom.setText("passiv");
		}

		return 0;
	}

	/**
	 * Methode zum Setzen der Membervariablen m_BefehlNotstrom
	 *
	 * @return 0  Funktion erfolgreich durchgeführt 1  Funktion nicht
	 *         erfolgreich durchgeführt -1  Funktionalität nicht implementiert.
	 */
	@Override
	public int setUsvBetrieb(final boolean befehl) {
		if (befehl) {
			jTextFieldBefehlUsvBetrieb.setText("aktiv");
		} else {
			jTextFieldBefehlUsvBetrieb.setText("passiv");
		}

		return 0;
	}

	@Override
	public void setInstance(final USVWrapper instance) {
		m_instance = instance;

	}

	@Override
	public int getBatterieSpannung() {
		return batterieSpannung;
	}

	@Override
	public int getBatterieTemperatur() {
		return batterieTemperatur;
	}

	@Override
	public int getBetriebsdauerBatterie() {
		return batterieBetriebsdauer;
	}

	@Override
	public int getUSVRestlaufzeit() {
		return batterieRestlaufzeit;
	}

} // @jve:decl-index=0:visual-constraint="10,10"
